@@ -34,7 +34,6 @@
 
 class SettingsUI : public QWidget, public Ui::SettingsWidget
 {
-    Q_OBJECT
 
     public:
         SettingsUI(QWidget *parent = 0)
@@ -104,7 +103,7 @@ SettingsDialog::SettingsDialog(TopLevel *toplevel, const QList<Tea> &teas)
     m_model=new TeaListModel( teas, this );
     ui->tealistTreeView->setModel( m_model );
 
-    connect(ui->tealistTreeView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this,SLOT(updateSelection(QItemSelection,QItemSelection)) );
+    connect(ui->tealistTreeView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &SettingsDialog::updateSelection);
 
     ui->removeButton->setEnabled( false );
     ui->upButton->setEnabled( false );
@@ -184,9 +183,9 @@ void SettingsDialog::newButtonClicked()
 
 void SettingsDialog::removeButtonClicked()
 {
-    QModelIndexList indexes = ui->tealistTreeView->selectionModel()->selectedIndexes();
+    const QModelIndexList indexes = ui->tealistTreeView->selectionModel()->selectedIndexes();
 
-    foreach(const QModelIndex &index, indexes) {
+    for (const QModelIndex &index : indexes) {
         // Only delete a row when column==0, otherwise the row will be delete
         // multiple times (the loop iterate over every cell, not over rows).
         if( index.column() == 0 ) {
@@ -292,9 +291,5 @@ void SettingsDialog::nameValueChanged(const QString &text)
     }
 }
 
-
-#include "settings.moc"
-#include "moc_settings.cpp"
-
 // kate: word-wrap off; encoding utf-8; indent-width 4; tab-width 4; line-numbers on; mixed-indent off; remove-trailing-space-save on; replace-tabs-save on; replace-tabs on; space-indent on;
 // vim:set spell et sw=4 ts=4 nowrap cino=l1,cs,U1:
